@@ -90,7 +90,7 @@ int maxdot_meandot(PyObject *self, PyObject *args)
                     counter++;
                 }
             }
-            if (counter == 0) {
+            if (counter != 0) {
                 cout[i][j] = mean/(double)counter;
             } else {
                 cout[i][j] = 0;
